==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/CodeDeploy/ListDeploymentConfigs.pm <==

package Paws::CodeDeploy::ListDeploymentConfigs {
  use Moose;
  has nextToken => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListDeploymentConfigs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::ListDeploymentConfigsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::ListDeploymentConfigs - Arguments for method ListDeploymentConfigs on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListDeploymentConfigs on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method ListDeploymentConfigs.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to ListDeploymentConfigs.

As an example:

  $service_obj->ListDeploymentConfigs(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 nextToken => Str

  

An identifier that was returned from the previous list deployment
configurations call, which can be used to return the next set of
deployment configurations in the list.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for ListDeploymentConfigs in Paws::CodeDeploy

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.04.tar.gz: Paws-0.04/lib/Paws/CodeDeploy/ListDeploymentConfigs.pm <==

package Paws::CodeDeploy::ListDeploymentConfigs {
  use Moose;
  has nextToken => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListDeploymentConfigs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::ListDeploymentConfigsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::ListDeploymentConfigs - Arguments for method ListDeploymentConfigs on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListDeploymentConfigs on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method ListDeploymentConfigs.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to ListDeploymentConfigs.

As an example:

  $service_obj->ListDeploymentConfigs(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 nextToken => Str

  

An identifier that was returned from the previous list deployment
configurations call, which can be used to return the next set of
deployment configurations in the list.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListDeploymentConfigs in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
